# Generated by Django 2.0.9 on 2018-11-19 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0013_remove_blog_image")]

    operations = [
        migrations.AddField(
            model_name="itunesartwork",
            name="original_height",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="itunesartwork",
            name="original_width",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.3 on 2018-11-05 12:43

import ckeditor_uploader.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [migrations.swappable_dependency(settings.AUTH_USER_MODEL)]

    operations = [
        migrations.CreateModel(
            name="Blog",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("description", models.CharField(max_length=500)),
                ("slug", models.SlugField()),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="cast_user",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.CreateModel(
            name="File",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("original", models.FileField(upload_to="blogs_files/")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.CreateModel(
            name="Gallery",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.CreateModel(
            name="Image",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                (
                    "original",
                    models.ImageField(
                        height_field="original_height",
                        upload_to="blogs_images/originals",
                        width_field="original_width",
                    ),
                ),
                ("original_height", models.PositiveIntegerField(blank=True, null=True)),
                ("original_width", models.PositiveIntegerField(blank=True, null=True)),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.CreateModel(
            name="Post",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("pub_date", models.DateTimeField(blank=True, null=True)),
                (
                    "visible_date",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                ("content", ckeditor_uploader.fields.RichTextUploadingField()),
                ("slug", models.SlugField()),
                (
                    "author",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "blog",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="cast.Blog"
                    ),
                ),
                ("galleries", models.ManyToManyField(to="cast.Gallery")),
                ("images", models.ManyToManyField(to="cast.Image")),
            ],
            options={"abstract": False},
        ),
        migrations.CreateModel(
            name="Video",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("original", models.FileField(upload_to="blogs_videos/")),
                (
                    "poster",
                    models.ImageField(
                        blank=True, null=True, upload_to="blogs_videos/poster/"
                    ),
                ),
                ("poster_seconds", models.FloatField(default=1)),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.AddField(
            model_name="post",
            name="videos",
            field=models.ManyToManyField(to="cast.Video"),
        ),
        migrations.AddField(
            model_name="gallery",
            name="images",
            field=models.ManyToManyField(to="cast.Image"),
        ),
        migrations.AddField(
            model_name="gallery",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL
            ),
        ),
    ]



# Generated by Django 2.0.9 on 2018-11-19 16:12

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [("cast", "0011_post_uuid")]

    operations = [
        migrations.CreateModel(
            name="ItunesArtWork",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                (
                    "original",
                    models.ImageField(
                        height_field="original_height",
                        upload_to="cast_images/itunes_artwork",
                        width_field="original_width",
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.AddField(
            model_name="blog",
            name="itunes_artwork",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="cast.ItunesArtWork",
            ),
        ),
    ]



import os


def storage_walk_paths(storage, cur_dir=""):
    dirs, files = storage.listdir(cur_dir)
    for directory in dirs:
        new_dir = os.path.join(cur_dir, directory)
        for path in storage_walk_paths(storage, cur_dir=new_dir):
            yield path
    for fname in files:
        path = os.path.join(cur_dir, fname)
        yield path



# Generated by Django 2.1.3 on 2018-11-09 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0002_auto_20181109_0640")]

    operations = [
        migrations.AddField(
            model_name="audio",
            name="duration",
            field=models.DurationField(blank=True, null=True),
        )
    ]



from django import template
from django.utils.safestring import mark_safe

register = template.Library()


@register.simple_tag(takes_context=True)
def image(context, pk):
    image = context["image"][pk]
    image_tag = (
        '<a href="{full}">'
        '  <img class="cast-image" src="{src}" srcset="{srcset}" sizes="100vw"></img>'
        "</a>"
    ).format(srcset=image.get_srcset(), src=image.img_xs.url, full=image.img_full.url)
    return mark_safe(image_tag)


@register.simple_tag(takes_context=True)
def video(context, pk):
    video = context["video"][pk]
    if video.poster:
        poster_url = video.poster.url
    else:
        poster_url = "/static/img/cast/Video-icon.svg"
    video_tag = (
        '<video class="cast-video" preload="auto" controls poster="{poster}">'
        '  <source src="{src}" type="video/mp4">'
        "  your browser does not support the video tag"
        "</video>"
    ).format(src=video.original.url, poster=poster_url)
    return mark_safe(video_tag)


@register.simple_tag(takes_context=True)
def audio(context, pk):
    audio_tag = f'<div id="audio_{pk}"></div>'
    return mark_safe(audio_tag)


# gallery tag


def get_modal_trigger(gallery_key, image, prev_img, next_img):
    srcset = image.get_srcset()
    prev_id = "img-{}".format(prev_img.pk) if prev_img is not None else "false"
    next_id = "img-{}".format(next_img.pk) if next_img is not None else "false"
    thumbnail_tag = (
        '<img id="img-{img_id}" class="cast-gallery-thumbnail" src="{src}" '
        'srcset="{srcset}" data-prev="{prev}" data-next="{next}" '
        'data-full="{full}"></img>'
    ).format(
        img_id=image.pk,
        prev=prev_id,
        next=next_id,
        srcset=srcset,
        src=image.img_xs.url,
        full=image.img_full.url,
    )
    return """
        <a src="#" class="cast-gallery-modal" data-toggle="modal" data-target="#galleryModal{key}">
            {thumbnail_tag}
        </a>
    """.format(
        thumbnail_tag=thumbnail_tag, key=gallery_key
    )


def get_image_thumb(image):
    srcset = image.get_srcset()
    thumbnail_tag = (
        '<img class="cast-gallery-thumbnail" src={src} ' 'srcset="{srcset}"</img>'
    ).format(src=image.img_xs.url, srcset=srcset)
    return """
        <a href="{full}"">
            {thumbnail_tag}
        </a>
    """.format(
        thumbnail_tag=thumbnail_tag, full=image.img_full.url
    )


def get_modal_tmpl():
    return """
        {thumbs}
        <!-- Modal -->
        <div class="modal fade" id="galleryModal{key}" tabindex="-1" role="dialog"
             aria-labelledby="galleryModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-lg cast-gallery-lg" role="document">
                <div class="modal-content cast-gallery-content">
                    <div class="modal-header cast-gallery-header">
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                        <div class="modal-body cast-gallery-body">
                        <a href=""><img class="modal-image cast-image" src="" srcset="" sizes="100vw"></img></a>
                    </div>
                    <div class="modal-footer cast-gallery-footer">
                        </div>
                    </div>
            </div>
        </div>
    """


def gallery_with_javascript(gallery, post):
    image_thumbs = [
        "<!-- Button trigger modal -->",
        '<div class="cast-gallery-container">',
    ]

    gallery_key = "{}_{}".format(post.pk, gallery.pk)
    prev_img, next_img = None, None
    images = list(gallery.images.all())
    for num, image in enumerate(images, 1):
        if num < len(images):
            next_img = images[num]
        else:
            next_img = None
        image_thumbs.append(get_modal_trigger(gallery_key, image, prev_img, next_img))
        prev_img = image
    image_thumbs.append("</div>")
    thumbs = "\n".join(image_thumbs)
    return get_modal_tmpl().format(thumbs=thumbs, key=gallery_key)


def gallery_without_javascript(gallery):
    image_thumbs = []
    for image in gallery.images.all():
        image_thumbs.append(get_image_thumb(image))
    return "\n".join(image_thumbs)


@register.simple_tag(takes_context=True)
def gallery(context, pk):
    use_javascript = context.get("javascript", True)
    post = context["post"]
    gallery = context["gallery"][pk]
    if use_javascript:
        gallery_html = gallery_with_javascript(gallery, post)
    else:
        gallery_html = gallery_without_javascript(gallery)

    return mark_safe(gallery_html)



# Generated by Django 2.0.9 on 2018-11-19 16:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("cast", "0012_auto_20181119_1612")]

    operations = [migrations.RemoveField(model_name="blog", name="image")]



# Generated by Django 2.1.3 on 2018-11-09 12:40

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("cast", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Audio",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("original", models.FileField(upload_to="cast_audio/")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.AlterField(
            model_name="file",
            name="original",
            field=models.FileField(upload_to="cast_files/"),
        ),
        migrations.AlterField(
            model_name="image",
            name="original",
            field=models.ImageField(
                height_field="original_height",
                upload_to="cast_images/originals",
                width_field="original_width",
            ),
        ),
        migrations.AlterField(
            model_name="video",
            name="original",
            field=models.FileField(upload_to="cast_videos/"),
        ),
        migrations.AlterField(
            model_name="video",
            name="poster",
            field=models.ImageField(
                blank=True, null=True, upload_to="cast_videos/poster/"
            ),
        ),
        migrations.AddField(
            model_name="post",
            name="audios",
            field=models.ManyToManyField(to="cast.Audio"),
        ),
    ]



from django.core.management.base import BaseCommand
from django.core.files.storage import default_storage
from django.core.files.storage import get_storage_class

from blogs.utils import storage_walk_paths


class Command(BaseCommand):
    help = "restoremedia files from local media root to s3"

    def handle(self, *args, **options):
        s3 = get_storage_class("storages.backends.s3boto3.S3Boto3Storage")()
        for path in storage_walk_paths(default_storage):
            if not s3.exists(path):
                print(path)
                with default_storage.open(path, "rb") as in_f:
                    s3.save(path, in_f)



from django.core.management.base import BaseCommand
from django.core.files.storage import default_storage
from django.core.files.storage import get_storage_class


class Command(BaseCommand):
    help = (
        "replace paths on s3 with local versions - useful for"
        " compressed videos for example"
    )

    def add_arguments(self, parser):
        parser.add_argument("paths", nargs="+", type=str)

    def handle(self, *args, **options):
        s3 = get_storage_class("storages.backends.s3boto3.S3Boto3Storage")()
        for path in options["paths"]:
            if default_storage.exists(path):
                if s3.exists(path):
                    s3.delete(path)
                with default_storage.open(path, "rb") as in_f:
                    s3.save(path, in_f)



import logging

from django.http import HttpResponse


logger = logging.getLogger(__name__)


class FileUploadResponseMixin:
    def get_success_url(self):
        return None

    def form_valid(self, form):
        model = form.save(commit=False)
        super().form_valid(form)
        return HttpResponse("{}".format(model.pk), status=201)



import logging

from django.contrib import admin
from watson.admin import SearchAdmin

from .models import (
    Blog,
    Post,
    File,
    Image,
    Video,
    Audio,
    Gallery,
    ItunesArtWork,
    ChapterMark,
)

logger = logging.getLogger(__name__)


class AdminUserMixin:
    def get_changeform_initial_data(self, request):
        return {"user": request.user, "author": request.user}


class BlogModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("title", "user")


admin.site.register(Blog, BlogModelAdmin)


class PostModelAdmin(AdminUserMixin, SearchAdmin):
    list_display = ("title", "author", "blog")
    search_fields = ("title", "content")

    class Media:
        js = ("js/cast/ckeditor_fix.js",)


admin.site.register(Post, PostModelAdmin)


class ImageModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("pk", "original", "user")
    fields = ("user", "original")


admin.site.register(Image, ImageModelAdmin)


class ItunesArtWorkModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("pk", "original")
    fields = ("original",)


admin.site.register(ItunesArtWork, ItunesArtWorkModelAdmin)


class FileModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("original", "user")
    fields = ("user", "original")


admin.site.register(File, FileModelAdmin)


class AudioAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("user", "title", "subtitle", "m4a", "mp3", "oga", "opus")
    fields = ("user", "title", "subtitle", "m4a", "mp3", "oga", "opus")


admin.site.register(Audio, AudioAdmin)


class ChapterMarkModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("start", "title", "link", "image", "audio")


admin.site.register(ChapterMark, ChapterMarkModelAdmin)


class VideoModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("pk", "user")

    def save_model(self, request, obj, form, change):
        logger.info("poster: {}".format(obj.poster))
        logger.info("form: {}".format(form.cleaned_data))
        if change and not form.cleaned_data["poster"]:
            logger.info("poster was cleared")
            obj.calc_poster = False
        super().save_model(request, obj, form, change)


admin.site.register(Video, VideoModelAdmin)


class GalleryModelAdmin(AdminUserMixin, admin.ModelAdmin):
    list_display = ("pk",)
    fields = ("user", "images")


admin.site.register(Gallery, GalleryModelAdmin)
